import { Plugins } from '@capacitor/core';
import { notAvailable, FeatureNotAvailableError } from './util/models';
import { isFeatureAvailable } from './util/feature-check';
import { useState } from 'react';
;
const availableFeatures = {
    getPhoto: isFeatureAvailable('Camera', 'getPhoto')
};
function useCamera() {
    const { Camera } = Plugins;
    const [photo, setPhoto] = useState();
    if (!availableFeatures.getPhoto) {
        return Object.assign({ getPhoto: () => { throw new FeatureNotAvailableError(); } }, notAvailable);
    }
    const getPhoto = async (options) => {
        const photoObject = await Camera.getPhoto(options);
        setPhoto(photoObject);
    };
    return {
        photo,
        getPhoto,
        isAvailable: true
    };
}
export const CameraHooks = {
    useCamera,
    availableFeatures
};
//# sourceMappingURL=useCamera.js.map