import { useState } from 'react';
import { Plugins } from '@capacitor/core';
import { notAvailable, FeatureNotAvailableError } from './util/models';
import { isFeatureAvailable } from './util/feature-check';
const availableFeatures = {
    useClipboard: isFeatureAvailable('Clipboard', 'useClipboard')
};
function useClipboard() {
    const { Clipboard } = Plugins;
    if (!(availableFeatures.useClipboard)) {
        return Object.assign({ getValue: () => { throw new FeatureNotAvailableError(); }, setValue: () => { throw new FeatureNotAvailableError(); } }, notAvailable);
    }
    const [data, setData] = useState();
    async function getValue() {
        const ret = await Clipboard.read({
            type: 'string'
        });
        setData(ret.value);
    }
    async function setValue(value) {
        await Clipboard.write({
            string: value
        });
    }
    return {
        value: data,
        getValue,
        setValue,
        isAvailable: true
    };
}
export const ClipboardHooks = {
    useClipboard,
    availableFeatures
};
//# sourceMappingURL=useClipboard.js.map